<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:template match="/">
    <html>
      <head>
        <title>D20 SRD 3.5 - Spells</title>
        <style type="text/css">       th {font-weight:bold;
          background-color: rgb(80%, 80%, 80%) }       dt
          {font-weight:bold; }       h2 {font-weight:bold;
          background-color: rgb(70%, 70%, 80%) }       caption
          {font-weight:bold; } </style>
      </head>
      <body>
        <h1 id="top">D20 System Reference Document v3.5 - Spells</h1>
        <p align="right">
          <a href="#legal">Legal Information</a>
          <img alt="D20 logo" src="D20_logo_4.jpg"/>
        </p>
        <hr/>
        <!-- table of contents -->
        <table border="border">
          <xsl:for-each select="spell-list/spell">
            <tr>
              <td>
                <a href="{concat('spell35.xml#',name)}">
                  <xsl:value-of select="name"/>
                </a>
              </td>
              <td>
                <xsl:apply-templates mode="content" select="shortdescription"/>
              </td>
            </tr>
          </xsl:for-each>
        </table>
        <!-- detailed spell info -->
        <xsl:for-each select="spell-list/spell">
          <h2 id="{name}">
            <xsl:value-of select="name"/>
          </h2>
          <xsl:value-of select="school"/>
          <xsl:if test="subschool"> (<xsl:value-of select="subschool"/>)</xsl:if>
          <xsl:if test="descriptor"> [<xsl:apply-templates
              mode="content" select="descriptor"/>]</xsl:if>
          <table border="border" cellpadding="3">
            <tr>
              <xsl:if test="level">
                <th>Level:</th>
                <td>
                  <xsl:apply-templates mode="content" select="level"/>
                </td>
              </xsl:if>
            </tr>
          </table>
          <table border="border" cellpadding="3">
            <tr>
              <xsl:if test="castingtime">
                <th>Casting Time:</th>
                <td>
                  <xsl:apply-templates mode="content" select="castingtime"/>
                </td>
              </xsl:if>
              <xsl:if test="duration">
                <th>Duration:</th>
                <td>
                  <xsl:apply-templates mode="content" select="duration"/>
                </td>
              </xsl:if>
            </tr>
          </table>
          <table border="border" cellpadding="3">
            <tr>
              <xsl:if test="range">
                <th>Range:</th>
                <td>
                  <xsl:apply-templates mode="content" select="range"/>
                </td>
              </xsl:if>
              <xsl:if test="target">
                <th>Target:</th>
                <td>
                  <xsl:apply-templates mode="content" select="target"/>
                </td>
              </xsl:if>
              <xsl:if test="area">
                <th>Area:</th>
                <td>
                  <xsl:apply-templates mode="content" select="area"/>
                </td>
              </xsl:if>
            </tr>
          </table>
          <table border="border" cellpadding="3">
            <tr>
              <xsl:if test="components">
                <th>Components:</th>
                <td>
                  <xsl:apply-templates mode="content" select="components"/>
                </td>
              </xsl:if>
              <xsl:if test="materialcomponents">
                <th>Material Components:</th>
                <td>
                  <xsl:apply-templates mode="content" select="materialcomponents"/>
                </td>
              </xsl:if>
              <xsl:if test="focus">
                <th>Focus:</th>
                <td>
                  <xsl:apply-templates mode="content" select="focus"/>
                </td>
              </xsl:if>
            </tr>
          </table>
          <table border="border" cellpadding="3">
            <tr>
              <xsl:if test="savingthrow">
                <th>Saving Throw:</th>
                <td>
                  <xsl:apply-templates mode="content" select="savingthrow"/>
                </td>
              </xsl:if>
              <xsl:if test="spellresistance">
                <th>Spell Resistance:</th>
                <td>
                  <xsl:apply-templates mode="content" select="spellresistance"/>
                </td>
              </xsl:if>
            </tr>
          </table>
          <dl>
            <dt>Description:</dt>
            <dd>
              <xsl:apply-templates mode="content" select="description"/>
            </dd>
            <dt>Quick Text:</dt>
            <dd>
              <xsl:apply-templates mode="content" select="shortdescription"/>
            </dd>
            <xsl:if test="effect">
              <dt>Effect:</dt>
              <dd>
                <xsl:apply-templates mode="content" select="effect"/>
              </dd>
            </xsl:if>
            <xsl:if test="xpcost">
              <dt>XP Cost:</dt>
              <dd>
                <xsl:apply-templates mode="content" select="xpcost"/>
              </dd>
            </xsl:if>
            <xsl:if test="reference">
              <dt>Reference:</dt>
              <dd>
                <xsl:apply-templates mode="content" select="reference"/>
              </dd>
            </xsl:if>
          </dl>
          <xsl:call-template name="divider"/>
        </xsl:for-each>
        <xsl:call-template name="legaldisclaimer"/>
      </body>
    </html>
  </xsl:template>
  <!-- several formatting transformations -->
  <xsl:template match="strong" mode="content">
    <strong>
      <xsl:value-of select="."/>
    </strong>
  </xsl:template>
  <xsl:template match="br" mode="content">
    <br/>
  </xsl:template>
  <xsl:template match="xref" mode="content">
    <a href="{concat(@doc, '.xml#',@topic)}">
      <xsl:value-of select="."/>
    </a>
  </xsl:template>
  <xsl:template match="table" mode="content">
    <table border="border">
      <!--title of table
-->
      <tr/>
      <th colspan="10">table:  <xsl:value-of select="@name"/>
      </th>
      <!--actual contents of table-->
      <xsl:apply-templates mode="content"/>
      <!--footnotes (if any)-->
      <xsl:if test="footnote">
        <tr>
          <td bgcolor="#f0f0f0" colspan="10">
            <xsl:for-each select="footnote">
              <em>
                <sup>
                  <xsl:value-of select="@name"/>
                </sup>
                <xsl:apply-templates mode="content"/>
              </em>
              <br/>
            </xsl:for-each>
          </td>
        </tr>
      </xsl:if>
    </table>
    <br/>
  </xsl:template>
  <xsl:template match="tr" mode="content">
    <tr align="{@align}">
      <xsl:apply-templates mode="content"/>
    </tr>
  </xsl:template>
  <xsl:template match="td" mode="content">
    <td>
      <xsl:apply-templates mode="content"/>
    </td>
  </xsl:template>
  <xsl:template match="th" mode="content">
    <th colspan="{@colspan}">
      <xsl:apply-templates mode="content"/>
    </th>
  </xsl:template>
  <xsl:template match="footnote" mode="content">
    <!-- do not show inline, we'll add it at the end of the table. -->
  </xsl:template>
  <xsl:template match="seefootnote" mode="content">
    <sup>
      <xsl:value-of select="@name"/>
    </sup>
  </xsl:template>
  <xsl:template name="legaldisclaimer">
    <h2 id="legal">Legal Info</h2>   The System Reference Document is a
    comprehensive toolbox consisting of    rules, races, classes, feats,
    skills, various systems, spells, magic    items, and monsters
    compatible with the <a href="http://www.wizards.com/d20/">d20
    System</a>   version of <a
      href="http://www.wizards.com/dnd/">Dungeons&amp; Dragons </a>
    and various other roleplaying games from <a
      href="http://www.wizards.com">Wizards of the Coast</a>.    You may
    consider this material Open Game Content under the <a
      href="http://www.wizards.com/d20/files/v35/Legal.rtf">Open Game
    License</a>,    and may use, modify, and distribute it.</xsl:template>
  <xsl:template name="divider">
    <p align="right">[<a href="#top">top</a>] [<a href="#legal">legal</a>]</p>
    <hr/>
  </xsl:template>
</xsl:stylesheet>
